
# Nanoleaf API Wrapper

A Python3 wrapper for the Nanoleaf API, capable of controlling both Nanoleaf Aurora and Nanoleaf Canvas.


## Usage

    nanoleaf = Nanoleaf(host="192.168.1.197")
    #Press and hold the on/off button for 5-7 seconds to allow authentication
    nanoleaf.authorize()
    nanoleaf.name

